@@ -12,6 +12,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 """Contains classes for the LightPipeline."""
+
+from sparknlp.internal import AnnotatorTransformer
 from sparknlp.base.multi_document_assembler import MultiDocumentAssembler
 
 import sparknlp.internal as _internal
@@ -66,6 +68,7 @@ class LightPipeline:
 
     def __init__(self, pipelineModel, parse_embeddings=False):
         self.pipeline_model = pipelineModel
+        self.parse_embeddings = parse_embeddings
         self._lightPipeline = _internal._LightPipeline(pipelineModel, parse_embeddings).apply()
 
     def _validateStagesInputCols(self):
@@ -92,8 +95,10 @@ class LightPipeline:
                 output_cols = stage.getOutputCols()
                 for output_col in output_cols:
                     annotator_types[output_col] = stage.outputAnnotatorType
-            else:
-                annotator_types[stage.getOutputCol()] = stage.outputAnnotatorType
+            elif isinstance(stage, AnnotatorApproach) or isinstance(stage, AnnotatorModel) or\
+                    isinstance(stage, AnnotatorTransformer):
+                if stage.outputAnnotatorType is not None:
+                    annotator_types[stage.getOutputCol()] = stage.outputAnnotatorType
         return annotator_types
 
     def _annotationFromJava(self, java_annotations):
@@ -123,13 +128,17 @@ class LightPipeline:
                                     annotation.metadata())
                 )
             else:
+                if self.parse_embeddings:
+                    embeddings = list(annotation.embeddings())
+                else:
+                    embeddings = []
                 annotations.append(
                     Annotation(annotation.annotatorType(),
                                annotation.begin(),
                                annotation.end(),
                                annotation.result(),
                                annotation.metadata(),
-                               [])
+                               embeddings)
                 )
         return annotations
 
